@@ -1,10 +1,11 @@
 package Graphics::Primitive::Component;
 use Moose;
-
-with 'MooseX::Clone';
+use MooseX::Storage;
 
 use overload ('""' => 'to_string');
 
+with Storage('format' => 'JSON', 'io' => 'File');
+
 use Forest::Tree;
 use Graphics::Primitive::Border;
 use Graphics::Primitive::Insets;
@@ -41,6 +42,18 @@ has 'margins' => (
     coerce => 1,
     trigger => sub { my ($self) = @_; $self->prepared(0); }
 );
+has 'minimum_height' => (
+    is => 'rw',
+    isa => 'Num',
+    default => sub { 0 },
+    trigger => sub { my ($self) = @_; $self->prepared(0); }
+);
+has 'minimum_width' => (
+    is => 'rw',
+    isa => 'Num',
+    default => sub { 0 },
+    trigger => sub { my ($self) = @_; $self->prepared(0); }
+);
 has 'name' => ( is => 'rw', isa => 'Str' );
 has 'origin' => (
     is => 'rw',
@@ -61,18 +74,6 @@ has 'parent' => (
     isa => 'Maybe[Graphics::Primitive::Component]',
     weak_ref => 1
 );
-has 'minimum_height' => (
-    is => 'rw',
-    isa => 'Num',
-    default => sub { 0 },
-    trigger => sub { my ($self) = @_; $self->prepared(0); }
-);
-has 'minimum_width' => (
-    is => 'rw',
-    isa => 'Num',
-    default => sub { 0 },
-    trigger => sub { my ($self) = @_; $self->prepared(0); }
-);
 has 'prepared' => ( is => 'rw', isa => 'Bool', default => sub { 0 } );
 has 'visible' => ( is => 'rw', isa => 'Bool', default => sub { 1 } );
 has 'width' => (
@@ -171,7 +172,7 @@ sub outside_height {
     return $w;
 }
 
-sub pack { }
+sub finalize { }
 
 sub prepare {
     my ($self, $driver) = @_;
@@ -242,7 +243,7 @@ width should be set for all components.
 
   $lm->do_layout($comp);
 
-=item B<pack>
+=item B<finalize>
 
 This final phase provides and opportunity for the component to do any final
 changes to it's internals before being passed to a driver for drawing.
@@ -251,11 +252,11 @@ Since the final height and width isn't known until this phase, it was
 impossible for it to position these internal components until now.  It may
 even defer creation of this components until now.
 
-B<It is not ok to defer all action to the pack phase.  If you do not
+B<It is not ok to defer all action to the finalize phase.  If you do not
 establish a minimum hieght and width during prepare then the layout manager
 may not provide you with enough space to draw.>
 
-    $driver->pack($comp);
+    $driver->finalize($comp);
 
 =item B<draw>
 
@@ -365,9 +366,9 @@ Get the height consumed by padding, margin and borders.
 
 Get the width consumed by padding, margin and borders.
 
-=item I<pack>
+=item I<finalize>
 
-Method provided to give component one last opportunity to pack it's contents
+Method provided to give component one last opportunity to put it's contents
 into the provided space.  Called after prepare.
 
 =item I<padding>
