@@ -1,7 +1,9 @@
 package Graphics::Primitive::Path;
 use Moose;
+use MooseX::Storage;
 
 with 'MooseX::Clone';
+with Storage (format => 'JSON', io => 'File');
 
 use MooseX::AttributeHelpers;
 
